@@ -6,8 +6,8 @@
 mod methods;
 mod traits;
 
-/// A configurable field follows tri-state logic.
-#[cfg_attr(feature = "serde", derive(Serialize, Deserialize))]
+/// A configurable field follows 3-state logic.
+#[cfg_attr(feature = "serde", derive(serde::Serialize, serde::Deserialize))]
 #[derive(Debug, Copy, Clone, PartialEq, Eq, Hash)]
 pub enum Setting<T>
 where
