@@ -25,14 +25,15 @@ impl<T> AddAssign<Option<T>> for Setting<T>
 where
     T: Default,
 {
+    /// here None = Initial
     fn add_assign(&mut self, rhs: Option<T>) {
         *self = match (&self, rhs) {
             (Initial, Some(rhs)) => Normal(rhs),
-            (Initial, None) => Unset,
+            (Initial, None) => Initial,
             (Unset, Some(rhs)) => Normal(rhs),
             (Unset, None) => Unset,
             (Normal(_), Some(rhs)) => Normal(rhs),
-            (Normal(_), None) => Unset,
+            (Normal(_), None) => return,
         }
     }
 }
